# judo
[![Travis build status](https://travis-ci.com/fragiletech/judo.svg)](https://travis-ci.com/fragiletech/judo)
[![Documentation Status](https://readthedocs.org/projects/fragile/badge/?version=latest)](https://judo.readthedocs.io/en/latest/?badge=latest)
[![Code coverage](https://codecov.io/github/fragiletech/judo/coverage.svg)](https://codecov.io/github/fragiletech/judo)
[![PyPI package](https://badgen.net/pypi/v/judo)](https://pypi.org/project/judo/)
[![Latest docker image](https://badgen.net/docker/pulls/fragiletech/judo)](https://hub.docker.com/r/fragiletech/judo/tags)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![license: MIT](https://img.shields.io/badge/license-MIT-green.svg)](https://opensource.org/licenses/MIT)

Common API for working with tensors in the context of machine learning research 